Recall a series of plots from the backfillz object using the ID from the summary() function

recall_plots(object, id = NULL)

Arguments

object

Backfillz or Stanfit object. Stanfit objects are converted to Backfillz object using the as_backfillz function.

id

Vector of strings giving the parameters to plot (e.g., c('mu', 'sd')).